# Modelo de la cámara obscura
# Necesitamos:
#  las coordenadas de la cámara
#  el punto del objeto donde ve la cámara
#  al vector de arriba
# Se los pasamos al programa en la línea de comandos
#
# Vamos a calcular los círculos proyectados
# que son elipses
# 29.06.2023

import sys
import numpy as np

n = len( sys.argv )
if n != 10 :
	print("Args: cx cy cz  ox oy oz  ax ay az" )
	sys.exit(1)

vc = np.zeros( (3,1) )
vc[0,0] = float( sys.argv[1] )
vc[1,0] = float( sys.argv[2] )
vc[2,0] = float( sys.argv[3] )

vo = np.zeros( (3,1) )
vo[0,0] = float( sys.argv[4] )
vo[1,0] = float( sys.argv[5] )
vo[2,0] = float( sys.argv[6] )

va = np.zeros( (3,1) )
va[0,0] = float( sys.argv[7] )
va[1,0] = float( sys.argv[8] )
va[2,0] = float( sys.argv[9] )

vv = vc - vo
vz = vv/np.linalg.norm( vv, axis=0 )

vv = np.cross( va, vz, axisa=0, axisb=0, axisc=0 )
vx = vv/np.linalg.norm( vv, axis=0 )

vy = np.cross( vz, vx, axisa=0, axisb=0, axisc=0 )

R = np.zeros( (3,3) )
R[0,:] = vx.T
R[1,:] = vy.T
R[2,:] = vz.T

# Hacemos la homografía como
# H = K R [e1 e2 -c]

K = np.array( [[ -1000,     0, 300 ],
               [     0, -1000, 200 ],
               [     0,     0,   1 ] ] )

I = np.eye( 3 )
I[:,2] = -vc[:,0]

H = K @ R @ I

# Las ecuaciones de los círculos
C1 = np.eye( 3 )
C1[2,2] = -1
C2 = np.eye( 3 )
C2[2,2] = -0.25

Hinv = np.linalg.inv( H )

# Las elipses

A1 = Hinv.T @ C1 @ Hinv
A2 = Hinv.T @ C2 @ Hinv

np.save( "A1", A1 )
np.save( "A2", A2 )
